;+
; NAME:
;   fpr
;
; PURPOSE: 
;   Compact expression for expressing a floating-point as a string. 
;   (Stands for floating-point-represent).  
;
; CALLING SEQUENCE:
;   str = fpr(val, fmt)
;       
; INPUTS:
;   val - A floating-point number
;   fmt - A string or float indicating the format as N.M, where N is the number of
;         characters before the decimal and M is the number of characters after the
;         decimal.
;       
; OUTPUTS: 
;   str - Output string.  Will have N+1+M characters.
;         Will be whitespace-padded before the decimal and 0-padded after the decimal.
;         If N is insufficient to contain the pre-decimal number of digits the string will
;         be a series of asterisks (*).
;
; Last modified 3 Apr 2012.  Documentation added 3 July 2022.
;-

function fpr, val, fmt
  if n_elements(val) eq 0 then return, ''
  if n_elements(fmt) eq 0 then return, clip(float(val))
  nleft = fix(fmt) > 1
  ndec = fix((fmt+0.001 - fix(fmt)) * 10)

  return, string(val, $
                 format='(f'+clip(nleft+ndec+(ndec gt 0))+'.'+clip(ndec)+')')
end

