;+
; NAME: 
;    headspec
;
; PURPOSE: 
;    Obtain the header from a spec file.  (Analogous to headfits)
;
; CALLING SEQUENCE: 
;    h = headspec(filename)
;       
; INPUTS:
;    filename - The name of a spec file.     
;
; OUTPUTS: 
;    h - The header array.  This is an array of string cards and can be processed using
;        sxpar(), sxaddpar(), etc. in the same way as a header obtained via the IDLAstro
;        routines from a FITS file.
;
; COMMENTS:
;    See documentation for writespec() for more information. 
;
; Last modified 24 Sep 2016.  Documentation added 3 July 2022.
;-

function headspec, filename

  ; reads the header of an ASCII spectrum in Perley's standard format, analogous to a fits file.

  close, 19  ; need to replace this with proper lookup
  nl = countlines(filename)  

  openr, 19, filename
  inline = ''
  header = ['']

  i = 0
  for l = 0, nl-1 do begin
     readf, 19, inline
     inline = clip(inline)
     if strlen(inline) eq 0 then continue
     if strmid(inline,0,1) eq '#' then begin
        inline = clip(strmid(inline,1))
        hline = processheaderline(inline)
        if hline ne '' then begin
          header = [header, clip(hline,78)]  ; might not be strictly valid
        endif
     endif else begin
        if l gt 1 then break
     endelse
  endfor

  close, 19
  h = header
  return, h

end

