function maxcrosscorrelate, y1, y2, xmin, xmax, xint, quality=quality

  ; finds the offset of y2 from y1, including non-integer offets.

  n = n_elements(y1)
  nint = long(n_elements(y1) / xint)

  x = findgen(n)
  xfine = findgen(nint)*(n*1.0/nint)

  y1fine = interpol(y1, x, xfine, /quadratic)
  y2fine = interpol(y2, x, xfine, /quadratic)

  nlag = (xmax-xmin)/xint+1
  lag_x = (xmax-xmin)*findgen(nlag)/(nlag-1) + xmin  ; lag in input units
  ;print, 'lag_x: ', lag_x[0], lag_x[1], lag_x[2], '...', lag_x[nlag-1]
  lag_i = fix(lag_x / xint)                                  ; lag in interpolated array unites (integer)
  ;print, 'lag_i: ', lag_i[0], lag_i[1], lag_i[2], '...', lag_i[nlag-1]

  correlation = c_correlate(y1fine, y2fine, lag_i)
  wmax = where(correlation eq max(correlation), ct)
  if ct gt 1 then begin
     ;print, 'Warning: multiple cross-corelated maxima'
     wmax = median(wmax)
  endif

  quality = max(correlation)

  offset = lag_x[wmax]
  return, offset

end


pro testmaxcrosscorrelate
 y1 = fltarr(100)
 y2 = fltarr(100)
 y1[10:20] = [0,1,0,1,2,3,2,1,0,1,0]
 y2[20:30] = [0,1,0,1,2,3,2,1,0,1,0]
 c = maxcrosscorrelate(y1, y2, -15., 15., 0.1)
 print, c
end

