;+
; NAME: 
;   nearest
;
; PURPOSE: 
;   Simple algorithm for identifying the nearest source in a list of source coordinates 
;   to the specified coordinate.   Cartesian XY geometry assumed.
;
; CALLING SEQUENCE:
;   index = nearest(x, y, xarr, yarr, mindist=mindist, count=count)
;       
; INPUTS:
;   x, y       - Search coordinates (cannot be vector)
;   xarr, yarr - Catalog coordinate arrays
;   mindist    - Search radius
;
; OPTIONAL OUTPUT KEYWORDS:
;   count      - Number of sources found within mindist
;
; OUTPUTS: 
;   index      - The index position in the xarr, yarr array of the nearest source.
;
; Last modified 2 Apr  2012.  Documentation added 3 July 2022.
;-


function nearest, x, y, xarr, yarr, mindist=mindist, count=count

      count = 0
      index = -1
      imindist = mindist

      for j = 0L, n_elements(xarr)-1 do begin
         dist = sqrt((x-xarr[j])^2+(y-yarr[j])^2)
         if dist lt imindist then begin
             imindist = dist
             index = j
             count = count + 1
         endif
     endfor

     return, index
end

