;+
; NAME: 
;    processheaderline
;
; PURPOSE: 
;    Process a line of a spec header to make it compatible with IDLAstro FITS I/O routines   
;    (Used by readspec, headspec, etc.)
;
; CALLING SEQUENCE: 
;    outline = processheaderline(inline)
;       
; INPUTS:
;    inline - Header line.   
;       
; OUTPUTS: 
;    outline - Header card line.
;
; Last modified 23 Jun 2018.  Documentation added 3 July 2022.
;-

function processheaderline, inline

   ; process a single line in a FITS-like ASCII header

   eqpos = strpos(inline, '=')
   if eqpos eq -1 then eqpos = strpos(inline, ':')
   ishist = strpos(inline,'HISTORY') eq 0
   iscomm = strpos(inline,'COMMENT') eq 0
   if eqpos le 0 and ishist eq 0 and iscomm eq 0 then return, ''
   if ishist or iscomm then begin
      ; no further processing 
      return, inline
   endif

   hline = ''
   hline += clip(strmid(inline,0,eqpos),8 > eqpos)
   if strtrim(hline,2) ne 'HISTORY' then hline += '= ' else hline += ' '
   slpos = strpos(inline, ' /', /reverse_search) ; comment separator
   if slpos lt eqpos then slpos = strlen(inline)

   val = clip(strmid(inline,eqpos+1,slpos-(eqpos+1)))
   if valid_num(val) eq 0 then begin
       ; enclose string values in quotes for full compatibility with sxpar
       if val eq '' then begin
          val = "''"
       endif else begin
         if strmid(clip(val),0,1) ne "'" then val = "'" + val
         if strmid(clip(val),strlen(clip(val))-1,1) ne "'" then val = val + "'"
       endelse
   endif 
   hline += val

   if slpos lt strlen(inline) then begin
      comment = clip(strmid(inline,slpos+2))
      if strlen(clip(comment)) gt 1 then hline += ' / ' + comment
   endif

   return, hline

end

