;+
; NAME: removeflatlines.pro
;
; PURPOSE: 
;     Routine used by lineflatcombine
;
; Last modified 10 Apr 2020.  Documentation added 2 July 2022.
;-

function removeflatlines, im, ydisc=ydisc, xcheck=xcheck
  
   if n_elements(ydisc) gt 0 then begin
      nx = (size(im)) [1]
      ny = (size(im)) [2]
      im1 = im[*,0:ydisc-1]
      im2 = im[*,ydisc:(ny-1)]
      im1 = removeflatlines(im1, xcheck=xcheck)
      im2 = removeflatlines(im2, xcheck=xcheck)
      outim = im
      outim[*,0:ydisc-1] = im1
      outim[*,ydisc:(ny-1)] = im2

      ;writefits, 'outim2.fits', outim
      return, outim
   endif

 
   ; remove strong, narrow features from a flat-field and divide by the response.

   nx = (size(im)) [1]
   ny = (size(im)) [2]

   x = indgen(nx)
   x10 = findgen(10*nx)/10.

   midy = ny/2

   refcut = median(im[*,midy-4:midy+4], dimension=2)
   refmed = median(refcut[where(refcut gt median(refcut))])
   refcut /= refmed
   refcut10 = interpol(refcut,indgen(nx),x10)

   maxshift = 7 ; pixels
   ;dx   = -maxshift   +indgen(   2*maxshift+1)
   dx10 = -maxshift*10+indgen(10*2*maxshift+1)
   dx = dx10/10.0
   wck10 = where(x10 ge xcheck[0] and x10 le xcheck[1])

   xarr = findgen(nx)
   x10arr = findgen(nx*10)/10
   yarr = findgen(ny)

   shift = fltarr(ny)*!values.f_nan

   sim = im*0 ; this will be a rectified 2D spectrum

   ;!p.multi = [0,3,3]
   ;window, 0

   for y = 0, ny-1 do begin
     herecut = median(im[*,(y-2)>0:(y+2)<(ny-1)], dimension=2)
     heremed = median(herecut[where(herecut gt median(herecut))])
     if heremed lt 0.25*refmed then continue
     herecut /= heremed
     herecut10 = interpol(herecut,indgen(nx),x10)

     cc = c_correlate(herecut10-median(herecut10,30), refcut10-median(refcut10,30), dx10)
     w = where(cc eq max(cc))
     bestxshift = (dx[w]) [0]

     shift[y] = bestxshift
     sim[*,y] = shift(herecut,bestxshift)

     ;if y mod 35 eq 10 then begin
     ;   plot, xarr, refcut, xrange=median(xcheck)+[-30,10], /nodata, /xsty, charsize=1.8, /ynoz
     ;   oplot, xarr, refcut, psym=10, thick=2, color=rgb(80,80,200) ; blue ref
     ;   oplot, x10arr[wck10], refcut10[wck10], color=rgb(60,60,255)
     ;   oplot, xarr, herecut, psym=10, thick=2 ; white here
     ;   oplot, x10arr[wck10], herecut10[wck10], color=rgb(150,150,150)
     ;   oplot, xarr, sim[*,y], color=rgb(255,0,0), psym=10
     ;endif

     ;if y eq 10 then window, 1
     ;if y eq 10 then plot, x10arr, herecut10-median(herecut10,30), /xsty, xrange=[1100,1300], psym=10
     ;if y eq 10 then oplot, x10arr, refcut10-median(refcut10,30), color=rgb(255,0,0), psym=10
     ;if y eq 10 then oplot, xarr, sim[*,y]-median(sim[*,y],30), color=rgb(0,255,0), psym=10
   endfor

   ;window, 1
   ;plot, shift, yrange=[-5,5], psym=10

   response = median(sim, dimension=2)

   good = where(finite(shift))
   sol = poly_fit(yarr[good], shift[good], 3)
   shiftmodel = poly(yarr, sol)   
   ;oplot, shiftmodel, col=rgb(0,255,0)

   divim = im*0
   for y = 0, ny-1 do begin
     divim[*,y] = interpol(response,xarr,xarr+shiftmodel[y])
   endfor

   outim = im / divim
   outim /= median(outim[xcheck[0]:xcheck[1],*])
   ;writefits, 'inim.fits', im
   ;writefits, 'sim.fits', sim
   ;writefits, 'divim.fits', divim
   ;writefits, 'outim.fits', outim

   return, outim

end

