;+
; NAME: ujy2mag2.pro
;
; PURPOSE: 
;       Convert a flux density in microJy to a magnitude.
;
; CALLING SEQUENCE: 
;       mag = ujy2mag(flux, filter)
;
; INPUTS:
;       flux = The flux in microJy.  Can be a vector.
;       filter = Standard filter string, or AB.  Can be vector.
;
; OPTIONAL INPUT KEYWORD PARAMETERS: none
;
; OPTIONAL OUTPUT KEYWORD PARAMETERS: none
; 
; OUTPUTS:
;       The (Pogson/logarithmic) magnitude of the source(s).
;
; REQUIREMENTS: none
;
; Last modified 2 Nov 2016.  Documentation added 2 Jul 2022.
;-

function ujy2mag, flux, filter

  ;units of microJy

  mag = 2.5*(zeropt(filter)-alog10(flux))
  negflux = where(flux le 0, ct)
  if ct gt 0 then mag[negflux] = 99
  return, mag

end

