; tool for checking response curves across multiple runs

function effarea, rwav, rresp, cam=cam
   camchar = strlowcase(strmid(cam,0,1))
   lrisversion = 3
         dwav = rwav-shift(rwav,1)
         dwav[0] = dwav[1]
         gain = 1
         if camchar eq 'r' and lrisversion eq 3 then gain = 1.18 ; ??
         if camchar eq 'r' and lrisversion eq 1 then gain = 2 ; ?????? guess!!!
         if camchar eq 'b' then gain = 1.63
         h = 6.6260755e-27
         nu = 2.998e18/rwav
         effectivearea_m2 = (rresp * gain * h * nu / dwav)/1e4
         fullsystemthoroughput = effectivearea_m2 / 73.3

   return, effectivearea_m2
end

pro plotallresponse, filestr, cam=cam, minpeak=minpeak, OKstars=OKstars

  if n_elements(OKstars) eq 0 then OKstars = ['LTT3218','BD+28','G191-B2B','Feige34','Feige67','Feige110']
; ,'BD+17','BD+33', HZ44??


  files = file_search(filestr, count=ct)
  if ct eq 0 then return

  hinfo = lrisheaderinfo(files)

  if n_elements(cam) gt 0 then begin
    cam = strmid(cam,0,1)
    wok = where(strmid(hinfo.camera,0,1) eq cam)
    files = files[wok]
    hinfo = hinfo[wok]
  endif

  ok = intarr(n_elements(files))
  for i = 0, n_elements(OKstars)-1 do begin
    ok[where(hinfo.object eq OKstars[i] or hinfo.grname eq '900/5500')] = 1
  endfor
  hinfo = hinfo[where(ok)]
  files = files[where(ok)]

  wok = where(hinfo.airmass lt 1.8 and hinfo.dichroic ne 'clear')
  files = files[wok]
  hinfo = hinfo[wok]

  gr = hinfo.grname
  configs = strmid(strupcase(hinfo.camera),0,1)+' '+hinfo.grname+' '+hinfo.filter+' D'+hinfo.dichroic
  configs = repstr(configs,'clear','')
  configs = repstr(configs,'Clear','')

  ugr = unique(gr)
  res = strarr(n_elements(ugr))
  cwa = strarr(n_elements(ugr))
  for i = 0, n_elements(ugr)-1 do res[i] = (strsplit(ugr[i],'/',/extract)) [0]
  for i = 0, n_elements(ugr)-1 do cwa[i] = (strsplit(ugr[i],'/',/extract)) [1]
  ugr = ugr[sort(fix(cwa))]

  gray = rgb(128,128,128)
  cg = ['1200/3400','400/3400','600/4000','300/5000']
  cgcol = [rgb(255,0,255),rgb(128,64,255),rgb(0,255,255),rgb(0,255,128)]
  cg = [cg,'300/5000','600/5000','900/5500','150/7500',$
           '600/7500','1200/7500','831/8200','400/8500',$
            '1200/9000','600/10000']
  cgcol = [cgcol,rgb(1,1,1),rgb(0,255,0),rgb(128,255,0),rgb(1,1,1),$
                 rgb(220,220,0),rgb(255,125,0),rgb(255,64,0),rgb(255,30,30),$
                 rgb(1,1,1),rgb(185,40,40)]


  xr = [3000,10300] 
  if n_elements(cam) gt 0 then begin
    if cam eq 'b' then xr = [3000,6800]
    if cam eq 'r' then xr = [5000,10300]
  endif
  yr = [0,18]
  plot, [0], [0], xtitle='Wavelength', ytitle='Effective Area (m!U2!N)', ysty=9, /xsty, /nodata, yrange=yr, xrange=xr
  axis, yaxis=1, yrange=yr/73.3, /ysty, ytitle='Full thoroughput'

  ;ugr = ['831/8200']

  for c = 0, n_elements(ugr)-1 do begin
    wg = where(gr eq ugr[c], ctg)
    gconfigs = unique(configs[wg], count=ctconfig)
    wmax = where(ctconfig eq max(ctconfig))
    config = gconfigs[wmax[0]] ; most common dichroic & filter setup within this grating/grism
    wc = where(configs eq config, ctc)
    print, config
    normv = fltarr(ctc)

    nwav = fix(xr[1]-xr[0])
    cuwav = xr[0]+findgen(nwav)
    cuarea = fltarr(ctc, nwav)+!values.f_nan

    for i = 0, ctc-1 do begin
      file = files[wc[i]]
      icam = hinfo[wc[i]].camera
      airmass = hinfo[wc[i]].airmass

      readcol, file, wav, obsf, eff, resp, telresp, /silent
      resp /= atm_attenuate(wav, airmass-1.0, /flux) ; zenithify
      area = effarea(wav, resp, cam=icam)

      if i eq 0 then begin
        wp = where(area gt percentile(area,90))
        midwav = median(wav[wp])
        normwavrange = midwav+[-500,500]
        if ugr[c] eq '831/8200' then normwavrange=[7500,7600]
      endif
      normv[i] = mean(area[where(wav gt normwavrange[0] and wav lt normwavrange[1])])

      print, '  ', strmid(hinfo[wc[i]].date,0,10), '  ', clip(hinfo[wc[i]].object,10), fpr(hinfo[wc[i]].airmass,2.2), ' ', normv[i], ' '+(cam eq 'r' ? clip(fix(round(hinfo[wc[i]].wavelength))) : '')

      ;oplot, wav, area
    endfor
    norma = percentile(normv,75)
      
    j = 0
    for i = 0, ctc-1 do begin
      if normv[i] lt 0.25*norma then continue
     
      file = files[wc[i]]
      icam = hinfo[wc[i]].camera
      airmass = hinfo[wc[i]].airmass

      readcol, file, wav, obsf, eff, resp, telresp, /silent
      resp /= atm_attenuate(wav, airmass-1.0, /flux)
      area = effarea(wav, resp, cam=icam)

      buf = 0
      if icam eq 'red' then buf = 35
      wokw = where(cuwav gt min(wav)+buf and cuwav lt max(wav)-buf, ctokw)
      cuarea[i,wokw] = interpol(area*norma/normv[i], wav, cuwav[wokw])

      ;oplot, wav, area*norma/normv[i], col=gray
      oplot, cuwav[wokw],  cuarea[i,wokw], col=gray
      j += 1
    endfor

    wcol = where(ugr[c] eq cg, ctcol)
    if ctcol gt 0 then col=cgcol[wcol[0]] else col=rgb(255,255,255)

    medarea = median(cuarea, dimension=1)
    oplot, cuwav, medarea, color=col, thick=1


   ; normv2 = normv
   ; cuarea = fltarr(ctc, nwav)+!values.f_nan
   ; for i = 0, ctc-1 do begin
   ;   file = files[wc[i]]
   ;   icam = hinfo[wc[i]].camera
   ;   airmass = hinfo[wc[i]].airmass
;
;      readcol, file, wav, obsf, eff, resp, telresp, /silent
;      resp /= atm_attenuate(wav, airmass-1.0, /flux)
;      area = effarea(wav, resp, cam=icam)
;
;      buf = 0
;      if icam eq 'red' then buf = 20
;      wokw = where(cuwav gt min(wav)+buf and cuwav lt max(wav)-buf, ctokw)
;      areai = interpol(area, wav, cuwav[wokw])
;
;      normv2[i] = median(areai/medarea[wokw])
;      cuarea[i,wokw] = interpol(area/normv2[i], wav, cuwav[wokw])
;    endfor
;    medarea = median(cuarea, dimension=1)
;    oplot, cuwav, medarea, color=col, thick=2





    outfile = 'medresponse'+strupcase(cam)+repstr(clip(ugr[c]),'/','-')+'.txt'
    openw, 1, outfile
    printf, 1, '# '+config
    for i = 0, n_elements(medarea)-1 do begin
      if finite(medarea[i]) then printf, 1, fix(cuwav[i]), medarea[i]
    endfor
    close, 1
    ;q = get_kbrd()
    ;if q eq 'q' then break

  endfor

end

pro plotmedianresponse

   psopen, 'effarea.eps', /encaps, xsize=9, ysize=4, /inches
   device, /color
   !p.font=0
   device, /times, font_index=17
   colors = transpose([[0,0,0],$    
                   [220,0,225],$   ; 1200/3400 B
                   [0,0,255],$     ;  400/3400 B
                   [0,128,128],$   ;  600/4000 B
                   [0,200,100],$   ;  300/5000 B
                   [0,200,100],$   ;  300/5000 R
                   [0,255,0],$     ;  600/5000 R
                   [80,210,0],$   ;  900/5500 R
                   [1,1,1],$       ;  150/7500 R
                   [255,125,0],$   ;  600/7500 R
                   [180,180,0],$   ; 1200/7500 R
                   [1,1,1],$       ;  831/8200 R
                   [255,30,30],$   ;  400/8500 R
                   [1,1,1],$       ; 1200/9000 R
                   [185,40,40]])   ;  600/10000 R
  tvlct, colors

  cg = ['1200/3400','400/3400','600/4000','300/5000',$
        '300/5000','600/5000','900/5500','150/7500',$
        '600/7500','1200/7500','831/8200','400/8500',$
        '1200/9000','600/10000']
  cgcol = 1+indgen(14)

  !p.multi = [0,2,1]

  for c = 0, 1 do begin
     if c eq 0 then cam = 'b'
     if c eq 1 then cam = 'r'
     if cam eq 'b' then xr = [3000,6600]
     if cam eq 'r' then xr = [5200,10350]
     if cam eq 'b' then !p.position = [0.06,0.12,0.44,0.99]
     if cam eq 'r' then !p.position = [0.46,0.12,0.99,0.99]
     yr = [0,18]
     xtitle='Wavelength'
     if c eq 0 then ytitle = 'Effective Area (m!U2!N)' else ytitle=''
     ;if c eq 1 then rytitle = 'Full thoroughput (%)' else rytitle=''
     if c eq 0 then ytf = '' else ytf='(A1)'
     ;if c eq 1 then rytf = '' else rytf='(A1)' ; ysty of 8 for thoroughput
     plot, [0], [0], xtitle=xtitle, ytitle=ytitle, ysty=1, /xsty, /nodata, yrange=yr, xrange=xr, ytickformat=ytf
     ;axis, yaxis=1, yrange=100*yr/73.3, /ysty, ytitle=rytitle, ytickformat=rytf

     rfiles = findfile('medresponse'+strupcase(cam)+'*.txt')
     rcwav = intarr(n_elements(rfiles))
     for i = 0, n_elements(rfiles)-1 do begin
         rcwav[i] = fix(strmid(rfiles[i],1+strpos(rfiles[i],'-'),strpos(rfiles[i],'.')-strpos(rfiles[i],'-')))
         print, rcwav[i]
     endfor
     rfiles = rfiles[sort(rcwav)]

     fc = 0
     bb = 0
     for f = 0, n_elements(rfiles)-1 do begin
       openr, 1, rfiles[f]
       inline = ''
       readf, 1, inline
       config = clip(strmid(inline,1))
       close, 1
       fc += 1
       gr = (strsplit(config,/extract)) [1]
       readcol, rfiles[f], wav, area, format='f,f', comment='#', /silent
       wcol = (where(gr eq cg, ctcol)) [0]
       if cam eq 'r' then area = median(area,20)
       if cam eq 'r' then area = convol(area,0.025+fltarr(40), /edge_mirror)
       oplot, wav, area, thick=3, color=cgcol[wcol]
       xyouts, !p.position[0]+0.03+bb, !p.position[3]-0.02-0.055*fc, /norm, gr, color=cgcol[wcol]
       if fc eq 3 or (cam eq 'b' and fc eq 2) then begin
         fc = 0
         bb += 0.1
       endif
     endfor
   endfor

   psclose
   !p.multi = 0
   !p.position = 0

end


