;+
; NAME:
;       seqfilter
;
; PURPOSE:
;       Determines if a file passes a user-specified filter.
;
; CALLING SEQUENCE:
;       result = seqfilter(hi, /nofilefilter)
;
; EXPLANATION:
;       This is an internal LPipe tool to allow for user sorting, e.g. only
;       processing a specific grating or target name.  The user filter is
;       kept in the lpar common (global) variable; this function accepts
;       the lrisheaderinfo header structure (hi) and returns 1 if it passes
;       the filter or 0 if it fails.  For individual files only.
;
; INPUTS:
;       hi = header structure (from lrisheaderinfo)
;
; OPTIONAL INPUT KEYWORDS:
;       /nofilefilter - Specify this to ignore filtering on the filename.
;
; OUTPUTS:
;      Returns 0 (did not pass) or 1 (passed)
;
; NOTES:
;      Primarily used by lrisselectfiles.
; 
;-
;------------------------------------------------------------------------------

function seqfilter, hi, nofilefilter=nofilefilter
  ; Pass the header data of a file and see if it passes the user's filter.

  common lrisauto, lpar

  if lpar.fileseq ne '' and keyword_set(nofilefilter) eq 0 then $
      if total(hi.framenum eq strseq(lpar.fileseq)) eq 0 then return, 1b
  if lpar.targetseq ne '' then simptarg = (strsplit(hi.target,'_',/extract)) [0]
  if lpar.targetseq ne '' then if total(simptarg eq lpar.targetseq) + total(hi.target eq lpar.targetseq) eq 0 then return, 1b
  if lpar.gratingseq ne '' then if total(hi.grname eq lpar.gratingseq) eq 0 then return, 1b
  if lpar.filterseq ne '' gt 0 then if total(hi.filter eq lpar.filterseq) eq 0 then return, 1b

  return, 0b

end

