;+
; NAME:
;       sortkoa
;
; PURPOSE:
;       Sort a group of files by night into nightly subdirectories.
;
; CALLING SEQUENCE:
;       sortkoa, filestr, [/rename]
;
; EXPLANATION:
;       Given a large group of files corresponding to multiple nights of 
;       observation, sorts them into subdirectories for each night.  The files
;       are stored in directories with eight-digit date codes, e.g. 20170101.
;       This is the same output convention used by unwrapkoa, but is for
;       individual files rather than tarballs.  Works on non-Keck data too.
;
; INPUTS:
;       filestr - Wildcard string indicating files to process.
;
; OPTIONAL INPUT KEYWORDS:
;       rename - Also rename the files (e.g. from KOA to at-telescope format.)
;
;-
;------------------------------------------------------------------------------

pro sortkoa, filestr, rename=rename

  if n_elements(filestr) eq 0 then filestr = '*.fits*'
  f = file_search(filestr, count=ctfits)
  if ctfits eq 0 then begin
    print, ' No files found.' 
    return
  endif

  for k = 0, ctfits-1 do begin
    if strpos(f[k],'.fits') eq -1 then begin
      print, ' '+f[k]+': '+' not a fits file?'
      continue
    endif
    h = headfits(f[k])
    deststr = rundatestr(sxpar(h,'DATE',/silent))
    if file_test(deststr) eq 0 then print, 'Creating '+deststr
    if file_test(deststr) eq 0 then spawn, 'mkdir '+deststr
    outfile = deststr+'/'+removepath(f[k])
    if file_test(outfile) eq 0 then begin
         file_move, f[k], outfile
         if keyword_set(rename) then lrisrename, outfile
    endif else begin
         print, outfile+' already exists?'
    endelse
  endfor

end

