;+
; NAME:
;      trsoutstring
;
; PURPOSE:
;      Convert a single aperture structure to a string for file output
;
; CALLING SEQUENCE:
;      trsoutstring, trs, nocomment=nocomment
;
; EXPLANATION:
;      See saveobjectposfile.pro for some more context.
;
; INPUTS:
;      tr - The (single) aperture/trace IDL structure.
;      /nocomment - Omit the comment section of the string.
;
; OUTPUTS:
;      A one-line formatted string for output to disk.
; 
;-
;------------------------------------------------------------------------------

function trsoutstring, trs, nocomment=nocomment
    filestr = repstr(trs.file,'.fits','')
    fileapstr = filestr
    if trs.apname ne '' then fileapstr += '|'+clip(trs.apname)
    if strlen(fileapstr) lt 34 then fileapstr = clip(fileapstr,34)
    outstr = clip(fileapstr,34)+' '+fpr(trs.yfix,5.2)+' '+fpr(trs.aprad,3.2) + '  ' ;
    addskys = trs.addsky ? '*' : '' ; note this defaults to on now and is always overridden
    if abs(trs.bakmin[1] - trs.bakmin[0]) lt 0.01 and abs(trs.bakmax[1] - trs.bakmax[0]) lt 0.01 then $
        outstr += clip(fpr(trs.bakmin[0],2.1))+'-'+clip(fpr(trs.bakmax[0],2.1))+addskys $
    else $
        outstr += clip(fpr(trs.bakmin[0],2.1))+'-'+clip(fpr(trs.bakmax[0],2.1))+'|'+$
                  clip(fpr(trs.bakmin[1],2.1))+'-'+clip(fpr(trs.bakmax[1],2.1))+addskys
        if repstr(trs.tracefile,'.trace','') ne filestr then $
        outstr += clip('',(70-strlen(outstr) > 1))+removepath(trs.tracefile)
    if keyword_set(nocomment) eq 0 then begin
      if strlen(outstr) lt 70 then outstr = clip(outstr,70) + '#' + trs.comment else $
                                   outstr = outstr + '# ' + trs.comment
    endif
    return, outstr
end

